# Utilitary functions used all over the package

- [`commandline_utils.py`](commandline_utils.py): Handles the command line input and provides the decorater used in [cli.py](cli.py)
- [`math.py`](math.py): All mathematical equations needed in the nonadditivity analysis.
- [`log.py`](log.py): Logging setup.
- [`types.py`](types.py): File containing some Type aliases for rdit molecules and Atoms.
- [`errors.py`](errors.py): Custom Exceptions.
